@@ -66,7 +66,7 @@
 ##' @rdname spatPomp
 ##'
 ##' @include pstop.R undefined.R
-##' @include rprocess_spec.R safecall.R skeleton_spec.R
+##' @include safecall.R 
 ##' @include spatPomp_class.R get_covariate_names.R
 ##' @importFrom rlang .data
 ##' @inheritParams pomp::pomp
@@ -191,7 +191,7 @@ setMethod(
     ## if missing workhorses, set to default
     if (missing(rinit)) rinit <- NULL
     if (missing(rprocess) || is.null(rprocess)) {
-      rprocess <- rproc_plugin()
+      rprocess <- new("rprocPlugin")
     }
     if (missing(dprocess)) dprocess <- NULL
     if (missing(rmeasure)) rmeasure <- NULL
@@ -202,7 +202,7 @@ setMethod(
     if (missing(munit_measure)) munit_measure <- NULL
     if (missing(runit_measure)) runit_measure <- NULL
     if (missing(skeleton) || is.null(skeleton)) {
-      skeleton <- skel_plugin()
+      skeleton <- new("skelPlugin")
     }
     if (missing(rprior)) rprior <- NULL
     if (missing(dprior)) dprior <- NULL
@@ -367,7 +367,6 @@ setMethod(
 
     unit_covarnames <- data@unit_covarnames
     if(missing(shared_covarnames))  shared_covarnames <- data@shared_covarnames
-    if(missing(unit_accumvars)) unit_accumvars <- data@unit_accumvars
     if(!missing(covar)){
       if(timename %in% names(covar)) tcovar <- timename
       else{
@@ -403,7 +402,7 @@ setMethod(
     if (missing(t0)) t0 <- data@t0
     if (missing(rinit)) rinit <- data@rinit
     if (missing(rprocess)) rprocess <- data@rprocess
-    else if (is.null(rprocess)) rprocess <- rproc_plugin()
+    else if (is.null(rprocess)) rprocess <- new("rprocPlugin")
     if (missing(dprocess)) dprocess <- data@dprocess
     if (missing(rmeasure)) rmeasure <- data@rmeasure
     if (missing(dmeasure)) dmeasure <- data@dmeasure
@@ -413,7 +412,7 @@ setMethod(
     if (missing(eunit_measure)) eunit_measure <- data@eunit_measure
     if (missing(runit_measure)) runit_measure <- data@runit_measure
     if (missing(skeleton)) skeleton <- data@skeleton
-    else if (is.null(skeleton)) skeleton <- skel_plugin()
+    else if (is.null(skeleton)) skeleton <- new("skelPlugin")
     if (missing(rprior)) rprior <- data@rprior
     if (missing(dprior)) dprior <- data@dprior
     if (missing(partrans)) partrans <- data@partrans
@@ -429,7 +428,10 @@ setMethod(
     if (!missing(covar)) pomp_covarnames <- paste0(rep(unit_covarnames,each=U),seq_len(U))
     else  pomp_covarnames <- get_covariate_names(data@covar)
     if (!missing(unit_accumvars)) pomp_accumvars <- paste0(rep(unit_accumvars,each=U),seq_len(U))
-    else pomp_accumvars <- data@accumvars
+    else {
+      pomp_accumvars <- data@accumvars
+      unit_accumvars <- data@unit_accumvars
+    }
     mparamnames <- paste("M_", paramnames, sep = "")
 
     ## We will always have a global giving us the number of spatial units
